==> maelophone_0.6.0-2.tar.gz: maelophone-0.6.0/src/opt/maelophone/stylokeys.py <==
from PyQt4.QtGui import QMainWindow, QGraphicsView
from PyQt4.QtCore import pyqtSignature, Qt, SIGNAL, QPoint




class styloKeys(QGraphicsView):
    """
    Class documentation goes here.
    """
    keyid=[1, 13, 13, 2, 3, 14, 14,15, 15,5, 6, 16, 16, 17, 17, 18, 18, 9, 10, 19, 19, 20, 20, 12, 0 ]
    lastbutton=13
    keyrelease=1
    def __init__(self, parent):
        QGraphicsView.__init__(self, parent)
        # some custom properties and functions will follow
        
    def mousePressEvent(self, event):    
        self.mousePressPos = QPoint(event.pos())
        self.x = self.mousePressPos.x()
        self.y = self.mousePressPos.y()
         #print "Mouse moved ", self.x,self.y
        #check to see if we aare inside the qgraphicsview,then see if we are in bottom or top half of keyboard
        if self.x<=635 and self.x>=0:
            if self.y>=50:self.buttonid=int(self.x/53)+1
            #otherwise need to find small button. upper keyboard divided into 24 keys
            else:
                tempbuttonid=int(self.x/26.5)
                self.buttonid=self.keyid[tempbuttonid]
        self.emit(SIGNAL("stylo changed"),self.buttonid)        
        self.keyrelease=0
        self.lastbutton=self.buttonid
        #print "keypressed", self.buttonid, self.x, self.y
        event.accept()
        
    def mouseReleaseEvent(self, event):
        self.emit(SIGNAL("stylo released"))
        event.accept()
        self.keyrelease=1
    
    def mouseMoveEvent(self, event):
        if self.keyrelease==1:return
        self.mousePressPos = QPoint(event.pos())
        self.x = self.mousePressPos.x()
        self.y = self.mousePressPos.y()
        #check to see if we aare inside the qgraphicsview,then see if we are in bottom or top half of keyboard
        if self.x<=635 and self.x>=0:
            if self.y>=50:self.buttonid=int(self.x/53)+1
            #otherwise need to find small button. upper keyboard divided into 24 keys
            else:
                tempbuttonid=int(self.x/26.5)
                self.buttonid=self.keyid[tempbuttonid]
             #has a key been pressed   
            if self.buttonid!=self.lastbutton:self.emit(SIGNAL("stylo changed"), self.buttonid)
            self.lastbutton=self.buttonid
        #print "mouse moved", self.buttonid, self.x, self.y, self.keyrelease
        event.accept()

==> maelophone_0.7.0-1.tar.gz: maelophone-0.7.0/src/opt/maelophone/stylokeys.py <==
# -*- coding: utf-8 -*-
from PyQt4.QtGui import QMainWindow, QGraphicsView
from PyQt4.QtCore import pyqtSignature, Qt, SIGNAL, QPoint




class styloKeys(QGraphicsView):
    """
    Class documentation goes here.
    """
    keyid=[1, 13, 13, 2, 3, 14, 14,15, 15,5, 6, 16, 16, 17, 17, 18, 18, 9, 10, 19, 19, 20, 20, 12, 0 ]
    lastbutton=13
    keyrelease=1
    keyevent=0
    def __init__(self, parent):
        QGraphicsView.__init__(self, parent)
        # some custom properties and functions will follow
        
    def mousePressEvent(self, event):
        self.getButtonid(event)
        self.emit(SIGNAL("stylo changed"),self.buttonid)        
        self.keyrelease=0
        #print "keypressed", self.buttonid, self.x, self.y
        self.lastbutton=self.buttonid
        event.accept()
        
    def mouseDoubleClickEvent(self, event):    
        self.getButtonid(event)
        self.emit(SIGNAL("stylo changed"),self.buttonid)   
        self.emit(SIGNAL("stylo changed"),self.buttonid)            
        self.keyrelease=1
        #print "keypressed", self.buttonid, self.x, self.y
        self.lastbutton=self.buttonid
        event.accept()
        
    def mouseReleaseEvent(self, event):
        self.emit(SIGNAL("stylo released"))
        self.keyrelease=1
        event.accept()
    
    def mouseMoveEvent(self, event):
        if self.keyrelease==1:return
        self.getButtonid(event)
        if self.buttonid!=self.lastbutton:self.emit(SIGNAL("stylo changed"), self.buttonid)
        #print "mouse moved", self.buttonid, self.x, self.y, self.buttonid
        self.lastbutton=self.buttonid
        event.accept()
      
    def getButtonid(self, event):
        self.mousePressPos = QPoint(event.pos())
        self.x = self.mousePressPos.x()
        self.y = self.mousePressPos.y()
        #check to see if we aare inside the qgraphicsview,then see if we are in bottom or top half of keyboard
        if self.x<=635 and self.x>=0:
            if self.y>=50:self.buttonid=int(self.x/53)+1
            #otherwise need to find small button. upper keyboard divided into 24 keys
            else:
                tempbuttonid=int(self.x/26.5)
                self.buttonid=self.keyid[tempbuttonid]
             #has a key been pressed
